/vpcs/{vpcs_id}/nio — GNS3 1.3.dev1 documentation

### Navigation

- index
- previous |
- GNS3 1.3.dev1 documentation »

# /vpcs/{vpcs_id}/nio

Contents

- /vpcs/{vpcs_id}/nio
  - POST /vpcs/{vpcs_id}/nio
    - Parameters
    - Response status codes
    - Input
      - Types
        - Ethernet
        - LinuxEthernet
        - NULL
        - TAP
        - UDP
        - UNIX
        - VDE
      - Body
    - Sample session

## POST /vpcs/{vpcs_id}/nio

ADD NIO to a VPCS

### Parameters

- vpcs_id: Id of VPCS instance

### Response status codes

- 201: Success of creation of NIO
- 409: Conflict

### Input

#### Types

##### Ethernet

Generic Ethernet Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
ethernet_device | ✔ | string | Ethernet device name e.g. eth0
type | ✔ | enum | Possible values: nio_generic_ethernet

##### LinuxEthernet

Linux Ethernet Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
ethernet_device | ✔ | string | Ethernet device name e.g. eth0
type | ✔ | enum | Possible values: nio_linux_ethernet

##### NULL

NULL Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
type | ✔ | enum | Possible values: nio_null

##### TAP

TAP Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
tap_device | ✔ | string | TAP device name e.g. tap0
type | ✔ | enum | Possible values: nio_tap

##### UDP

UDP Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
lport | ✔ | integer | Local port
rhost | ✔ | string | Remote host
rport | ✔ | integer | Remote port
type | ✔ | enum | Possible values: nio_udp

##### UNIX

UNIX Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
local_file | ✔ | string | path to the UNIX socket file (local)
remote_file | ✔ | string | path to the UNIX socket file (remote)
type | ✔ | enum | Possible values: nio_unix

##### VDE

VDE Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
control_file | ✔ | string | path to the VDE control file
local_file | ✔ | string | path to the VDE control file
type | ✔ | enum | Possible values: nio_vde

#### Body

Name | Mandatory | Type | Description
--- | --- | --- | ---
id | ✔ | integer | VPCS device instance ID
nio | ✔ | UDP, Ethernet, LinuxEthernet, TAP, UNIX, VDE, NULL | Network Input/Output
port | ✔ | integer | Port number
port_id | ✔ | integer | Unique port identifier for the VPCS instance

### Sample session

    curl -i -xPOST 'http://localhost:8000/vpcs/{vpcs_id}/nio' -d '{"id": 42, "nio": {"local_file": "/tmp/test", "remote_file": "/tmp/remote", "type": "nio_unix"}, "port": 0, "port_id": 0}'

    POST /vpcs/{vpcs_id}/nio HTTP/1.1
    {
        "id": 42,
        "nio": {
            "local_file": "/tmp/test",
            "remote_file": "/tmp/remote",
            "type": "nio_unix"
        },
        "port": 0,
        "port_id": 0
    }

    HTTP/1.1 200
    CONNECTION: close
    CONTENT-LENGTH: 62
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 aiohttp/0.13.1
    X-ROUTE: /vpcs/{vpcs_id}/nio

    {
        "console": 4242,
        "name": "PC 2",
        "vpcs_id": 42
    }

### Navigation

- index
- previous |
- GNS3 1.3.dev1 documentation »